@@ -6,16 +6,19 @@ from fakts.fakts import Fakts, get_current_fakts
 
 Class = TypeVar("Class")
 
-class Config(BaseSettings):
 
+class Config(BaseSettings):
     class Config:
         extra = "ignore"
         group = "undefined"
 
-
     @classmethod
-    def from_fakts(cls: Type[Class], fakts: Fakts = None, **overwrites) -> Class:
+    async def from_fakts(
+        cls: Type[Class], fakts: Fakts = None, bypass_middleware=False, **overwrites
+    ) -> Class:
         group = cls.__config__.group
-        assert group is not "undefined", f"Please overwrite the Metaclass Config parameter group and point at your group {cls}"
+        assert (
+            group != "undefined"
+        ), f"Please overwrite the Metaclass Config parameter group and point at your group {cls}"
         fakts = fakts or get_current_fakts()
-        return cls(**fakts.load_group(group))
\ No newline at end of file
+        return cls(**await fakts.aget(group, bypass_middleware=bypass_middleware))
